RetryDelayMaxMs

Struct RetryDelayMaxMs 

pub struct RetryDelayMaxMs(/* private fields */);
The maximum retry for a retry attempt in milliseconds. Default is 5 seconds.

Implementations

Source

impl RetryDelayMaxMs

pub fn new<T: Into<u64>>(v: T) -> Self

Source

impl RetryDelayMaxMs

pub fn into_inner(self) -> u64

Returns the inner representation

Source

impl RetryDelayMaxMs

pub const ENV_TYPE_NAME: &'static str

The default name of the environment variable for this type.

The name of the environment variable is “ RETRY_DELAY_MAX_MS “

pub fn try_from_env() -> Result<Option<Self>, Error>

Initialize from the environment. Returns None if the value was not found and fails if the value could not be parsed. The name of the environment variable is “CONDOW_ RETRY_DELAY_MAX_MS “

pub fn try_from_env_prefixed<T: Into<String>>( prefix: T, ) -> Result<Option<Self>, Error>

Initialize from the environment. Returns None if the value was not found and fails if the value could not be parsed. The name of the environment variable is “prefix_ RETRY_DELAY_MAX_MS “

The underscore and prefix will be omitted if prefix is empty.

pub fn try_from_env_named<T: AsRef<str>>( var_name: T, ) -> Result<Option<Self>, Error>

Initialize from the environment. Returns None if the value was not found and fails if the value could not be parsed. The name of the environment variable is var_name.

pub fn try_from_env_type_name() -> Result<Option<Self>, Error>

Initialize from the environment. Returns None if the value was not found and fails if the value could not be parsed. The name of the environment variable is “ RETRY_DELAY_MAX_MS “

pub fn from_env() -> Result<Self, Error>

Initialize from the environment. Fails if the value was not found or if the value could not be parsed. The name of the environment variable is “CONDOW_ RETRY_DELAY_MAX_MS “

pub fn from_env_prefixed<T: Into<String>>(prefix: T) -> Result<Self, Error>

Initialize from the environment. Fails if the value was not found or if the value could not be parsed. The name of the environment variable is “prefix_ RETRY_DELAY_MAX_MS “

The underscore and prefix will be omitted if prefix is empty.

pub fn from_env_named<T: AsRef<str>>(var_name: T) -> Result<Self, Error>

Initialize from the environment. Fails if the value was not found or if the value could not be parsed. The name of the environment variable is var_name.

pub fn from_env_type_name() -> Result<Self, Error>

Initialize from the environment. Fails if the value was not found or if the value could not be parsed. The name of the environment variable is “ RETRY_DELAY_MAX_MS “

pub fn from_env_opt() -> Option<Self>

Initialize from the environment. Returns None if the value could not be read for any reason. The name of the environment variable is “CONDOW_ RETRY_DELAY_MAX_MS “

pub fn from_env_opt_prefixed<T: Into<String>>(prefix: T) -> Option<Self>

Initialize from the environment. Returns None if the value could not be read for any reason. The name of the environment variable is “prefix_ RETRY_DELAY_MAX_MS “

The underscore and prefix will be omitted if prefix is empty.

pub fn from_env_opt_named<T: AsRef<str>>(var_name: T) -> Option<Self>

Initialize from the environment. Returns None if the value could not be read for any reason. The name of the environment variable is var_name.

pub fn from_env_opt_type_name() -> Option<Self>

Initialize from the environment. Returns None if the value could not be read for any reason. The name of the environment variable is “ RETRY_DELAY_MAX_MS “

Methods from Deref<Target = u64>

1.43.0 · Source

pub const MIN: u64 = 0u64

1.43.0 · Source

pub const MAX: u64 = 18_446_744_073_709_551_615u64

1.53.0 · Source

pub const BITS: u32 = 64u32