RandomAccessReader

Struct RandomAccessReader 

pub struct RandomAccessReader { /* private fields */ }
Implements AsyncRead and AsyncSeek

This reader allows for random access on the BLOB.

Random access on a remote BLOB via a reader is a rather unusual case and is provided to interface with libraries which are based on reading data via AsyncRead and AsyncSeek.

Behaviour

The download is initiated once the first bytes have been queried from the reader. Seek does not intiate a download but currently forces a new download to be started once the reader is polled for bytes again.

The BLOB is only downloaded concurrently if prefetching is enabled via FetchAheadMode::Bytes or FetchAheadMode::ToEnd. The In these cases the number of bytes to be downloaded must be greater than the configured part size for concurrent downloading.

Implementations

Source

impl RandomAccessReader

pub fn new<F, FM>( get_reader: F, bounds: InclusiveRange, fetch_ahead_mode: FM, ) -> Self

Will create a reader with the given known size of the BLOB.

pub fn pos(&self) -> u64

Returns the current offset of the next byte to read.

The offset is from the start of the BLOB.

Source

impl RandomAccessReader