pub struct RetryDelayFactor(/* private fields */);Expand description
The factor the previous retry is multiplied by. This is actually what makes it exponentially when greater than 1.0. Default is 1.5.
Implementations
Sourceimpl RetryDelayFactor
impl RetryDelayFactor
Sourcepub fn into_inner(self) -> f64
pub fn into_inner(self) -> f64
Returns the inner representation
Sourceimpl RetryDelayFactor
impl RetryDelayFactor
Sourcepub const ENV_TYPE_NAME: &'static str
pub const ENV_TYPE_NAME: &'static str
The default name of the environment variable for this type.
The name of the environment variable is “ RETRY_DELAY_FACTOR “
Sourcepub fn try_from_env() -> Result<Option<Self>, Error>
pub fn try_from_env() -> Result<Option<Self>, Error>
Initialize from the environment.
Returns None if the value was not found and fails if the value could not be parsed.
The name of the environment variable is “CONDOW_
RETRY_DELAY_FACTOR
“
Sourcepub fn try_from_env_prefixed<T: Into<String>>(
prefix: T,
) -> Result<Option<Self>, Error>
pub fn try_from_env_prefixed<T: Into<String>>( prefix: T, ) -> Result<Option<Self>, Error>
Initialize from the environment.
Returns None if the value was not found and fails if the value could not be parsed.
The name of the environment variable is “prefix_
RETRY_DELAY_FACTOR
“
The underscore and prefix will be omitted if prefix is empty.
Sourcepub fn try_from_env_named<T: AsRef<str>>(
var_name: T,
) -> Result<Option<Self>, Error>
pub fn try_from_env_named<T: AsRef<str>>( var_name: T, ) -> Result<Option<Self>, Error>
Initialize from the environment.
Returns None if the value was not found and fails if the value could not be parsed.
The name of the environment variable is var_name.
Sourcepub fn try_from_env_type_name() -> Result<Option<Self>, Error>
pub fn try_from_env_type_name() -> Result<Option<Self>, Error>
Initialize from the environment.
Returns None if the value was not found and fails if the value could not be parsed.
The name of the environment variable is “
RETRY_DELAY_FACTOR
“
Sourcepub fn from_env() -> Result<Self, Error>
pub fn from_env() -> Result<Self, Error>
Initialize from the environment. Fails if the value was not found or if the value could not be parsed. The name of the environment variable is “CONDOW_ RETRY_DELAY_FACTOR “
Sourcepub fn from_env_prefixed<T: Into<String>>(prefix: T) -> Result<Self, Error>
pub fn from_env_prefixed<T: Into<String>>(prefix: T) -> Result<Self, Error>
Initialize from the environment.
Fails if the value was not found or if the value could not be parsed.
The name of the environment variable is “prefix_
RETRY_DELAY_FACTOR
“
The underscore and prefix will be omitted if prefix is empty.
Sourcepub fn from_env_named<T: AsRef<str>>(var_name: T) -> Result<Self, Error>
pub fn from_env_named<T: AsRef<str>>(var_name: T) -> Result<Self, Error>
Initialize from the environment.
Fails if the value was not found or if the value could not be parsed.
The name of the environment variable is var_name.
Sourcepub fn from_env_type_name() -> Result<Self, Error>
pub fn from_env_type_name() -> Result<Self, Error>
Initialize from the environment. Fails if the value was not found or if the value could not be parsed. The name of the environment variable is “ RETRY_DELAY_FACTOR “
Sourcepub fn from_env_opt() -> Option<Self>
pub fn from_env_opt() -> Option<Self>
Initialize from the environment.
Returns None if the value could not be read for any reason.
The name of the environment variable is “CONDOW_
RETRY_DELAY_FACTOR
“
Sourcepub fn from_env_opt_prefixed<T: Into<String>>(prefix: T) -> Option<Self>
pub fn from_env_opt_prefixed<T: Into<String>>(prefix: T) -> Option<Self>
Initialize from the environment.
Returns None if the value could not be read for any reason.
The name of the environment variable is “prefix_
RETRY_DELAY_FACTOR
“
The underscore and prefix will be omitted if prefix is empty.
Sourcepub fn from_env_opt_named<T: AsRef<str>>(var_name: T) -> Option<Self>
pub fn from_env_opt_named<T: AsRef<str>>(var_name: T) -> Option<Self>
Initialize from the environment.
Returns None if the value could not be read for any reason.
The name of the environment variable is var_name.
Sourcepub fn from_env_opt_type_name() -> Option<Self>
pub fn from_env_opt_type_name() -> Option<Self>
Initialize from the environment.
Returns None if the value could not be read for any reason.
The name of the environment variable is “
RETRY_DELAY_FACTOR
“
Methods from Deref<Target = f64>
pub const RADIX: u32 = 2u32
pub const MANTISSA_DIGITS: u32 = 53u32
pub const DIGITS: u32 = 15u32
pub const EPSILON: f64 = 2.2204460492503131E-16f64
pub const MIN: f64 = -1.7976931348623157E+308f64
pub const MIN_POSITIVE: f64 = 2.2250738585072014E-308f64
pub const MAX: f64 = 1.7976931348623157E+308f64
pub const MIN_EXP: i32 = -1_021i32
pub const MAX_EXP: i32 = 1_024i32
pub const MIN_10_EXP: i32 = -307i32
pub const MAX_10_EXP: i32 = 308i32
pub const NAN: f64 = NaN_f64
pub const INFINITY: f64 = +Inf_f64
pub const NEG_INFINITY: f64 = -Inf_f64
1.62.0 · Sourcepub fn total_cmp(&self, other: &f64) -> Ordering
pub fn total_cmp(&self, other: &f64) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f64. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f64,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f64::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f64::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f64::NAN` could be positive or negative, which will affect the sort order.
if f64::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f64::NAN, -5.0, 0.1, 10.0, 99.0, f64::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f64::INFINITY, f64::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl Clone for RetryDelayFactor
impl Clone for RetryDelayFactor
Sourcefn clone(&self) -> RetryDelayFactor
fn clone(&self) -> RetryDelayFactor
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more